@@ -3,7 +3,7 @@
 # Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 # Copyright (c) 2016 Ashish Gulhati <biz-btc at ashish dot neomailbox.com>
 #
-# $Id: lib/Business/Bitcoin.pm v1.10 Thu Dec 29 13:32:18 2016 -0500 $
+# $Id: lib/Business/Bitcoin.pm v1.7 Thu Dec 29 11:03:49 2016 -0500 $
 
 use strict;
 
@@ -18,7 +18,7 @@ use Business::Bitcoin::Request;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.10 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.7 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my $class = shift;
@@ -37,8 +37,6 @@ sub new {
                                                          refid text UNIQUE,
 		                                         created int NOT NULL
 		                                        );');
-      return undef unless $db->do('CREATE INDEX idx_requests_address ON requests(address);');
-      return undef unless $db->do('CREATE INDEX idx_requests_refid ON requests(refid);');
       my $startindex = $args{StartIndex} || 0;
       $startindex--;
       return unless $db->do("INSERT INTO SQLITE_SEQUENCE values ('requests',$startindex);");
@@ -58,12 +56,7 @@ sub request {                      # Create a Bitcoin payment request
   my $startindex = $self->db->selectcol_arrayref("SELECT seq from SQLITE_SEQUENCE WHERE name='requests';")->[0];
   my %forcezero; %forcezero = ( StartIndex => 0 ) if $startindex == -1;
 
-  my $req = new Business::Bitcoin::Request (_BizBTC => $self, %args, %forcezero);
-}
-
-sub findreq {                      # Retrieve a previously created request
-  my ($self, %args) = @_;
-  my $req = _find Business::Bitcoin::Request (_BizBTC => $self, %args);
+  my $req = new Business::Bitcoin::Request (%args, _BizBTC => $self, kucmd => $self->kucmd, %forcezero);
 }
 
 sub AUTOLOAD {
@@ -88,8 +81,8 @@ Business::Bitcoin - Easy and secure way to accept Bitcoin payments online
 
 =head1 VERSION
 
- $Revision: 1.10 $
- $Date: Thu Dec 29 13:32:18 2016 -0500 $
+ $Revision: 1.7 $
+ $Date: Thu Dec 29 11:03:49 2016 -0500 $
 
 =head1 SYNOPSIS
 
@@ -103,21 +96,15 @@ wallet private key offline.
                                         XPUB => 'xpub...',
                                         Create => 1);
 
-    my $req = $bizbtc->request(Amount => 4200);
+    my $request = $bizbtc->request(Amount => 4200);
 
-    print 'Please pay '           . $req->amount . ' Satoshi ' .
-          'to Bitcoin address '   . $req->address . ".\n" .
-          'Once the payment has ' . $req->confirmations , ' confirmations, ' .
+    print 'Please pay '           . $request->amount . ' Satoshi ' .
+          'to Bitcoin address '   . $request->address . ".\n" .
+          'Once the payment has ' . $request->confirmations , ' confirmations, ' .
           "press <enter> to continue.\n";
     readline(*STDIN);
 
-    print ($req->verify ? "Verified\n" : "Verification failed\n");
-
-    print "Enter a request address to verify a payment.\n";
-    my $address = <STDIN>; chomp $address;
-
-    my $req2 = $bizbtc->findreq(Address => $address);
-    print ($req2->verify ? "Verified\n" : "Verification failed\n");
+    print ($request->verify ? "Verified\n" : "Verification failed\n");
 
 =head1 HOW TO USE
 
@@ -189,32 +176,10 @@ The following optional named arguments can be provided:
 Confirmations - The number of confirmations needed to verify payment
 of this request. The default is 5.
 
-Reference - Optional reference ID to be associated with the requst, to
+Ref - Optional reference ID to be associated with the requst, to
 facilitate integration with existing ordering systems. If you provide
 a reference ID it should be unique for each request.
 
-=head2 findreq
-
-Find a previously created payment request, by either Address or
-Reference. Returns a Business::Bitcoin::Request object if successful,
-or undef on error. Exactly one of the following named arguments is
-required:
-
-=over
-
-Address - The receiving address associated with the payment request
-
-Reference - The reference ID associated with the payment request
-
-=back
-
-The following optional named argument can be provided:
-
-=over
-
-Confirmations - The number of confirmations needed to verify payment
-of this request. The default is 5.
-
 =back
 
 =head1 ACCESSORS
